==> PettingZoo-0.1.7.tar.gz: PettingZoo-0.1.7/pettingzoo/atari/__init__.py <==
from .games import boxing as boxing_v0
from .games import combat_tank as combat_tank_v0
from .games import combat_tankpong as combat_tankpong_v0
from .games import combat_invisible_tank as combat_invisible_tank_v0
from .games import combat_invisible_tankpong as combat_invisible_tankpong_v0
from .games import combat_biplane as combat_biplane_v0
from .games import combat_jet as combat_jet_v0
from .games import double_dunk as double_dunk_v0
from .games import entombed as entombed_v0
from .games import flag_capture as flag_capture_v0
from .games import joust as joust_v0
from .games import ice_hockey as ice_hockey_v0
from .games import maze_craze_fully_seen as maze_craze_fully_seen_v0
from .games import maze_craze_partial_vis as maze_craze_partial_vis_v0
from .games import maze_craze_invisible as maze_craze_invisible_v0
from .games import maze_craze_robbers as maze_craze_robbers_v0
from .games import maze_craze_capture as maze_craze_capture_v0
from .games import maze_craze_blockade as maze_craze_blockade_v0
from .games import mario_bros as mario_bros_v0
from .games import othello as othello_v0
from .games import pong as pong_v0
from .games import pong_basketball as pong_basketball_v0
from .games import space_invaders_easy as space_invaders_easy_v0
from .games import space_invaders_difficult as space_invaders_difficult_v0
from .games import space_invaders_alternating as space_invaders_alternating_v0
from .games import surround as surround_v0
from .games import surround_erase as surround_erase_v0
from .games import tennis as tennis_v0
from .games import video_checkers as video_checkers_v0
from .games import wizard_of_wor as wizard_of_wor_v0
from .games import warlords as warlords_v0
from .games import pong_four_player as pong_four_player_v0
from .games import pong_quadrapong as pong_quadrapong_v0
from .games import pong_volleyball as pong_volleyball_v0

==> PettingZoo-0.1.9.tar.gz: PettingZoo-0.1.9/pettingzoo/atari/__init__.py <==
from .games import boxing as boxing_v0
from .games import combat_tank as combat_tank_v0
from .games import combat_tankpong as combat_tankpong_v0
from .games import combat_invisible_tank as combat_invisible_tank_v0
from .games import combat_invisible_tankpong as combat_invisible_tankpong_v0
from .games import combat_biplane as combat_biplane_v0
from .games import combat_jet as combat_jet_v0
from .games import double_dunk as double_dunk_v0
from .games import entombed_competitive as entombed_competitive_v0
from .games import entombed_cooperative as entombed_cooperative_v0
from .games import flag_capture as flag_capture_v0
from .games import joust as joust_v0
from .games import ice_hockey as ice_hockey_v0
from .games import maze_craze_fully_seen as maze_craze_fully_seen_v0
from .games import maze_craze_partial_vis as maze_craze_partial_vis_v0
from .games import maze_craze_invisible as maze_craze_invisible_v0
from .games import maze_craze_robbers as maze_craze_robbers_v0
from .games import maze_craze_blockade as maze_craze_blockade_v0
from .games import mario_bros as mario_bros_v0
from .games import othello as othello_v0
from .games import pong as pong_v0
from .games import pong_basketball as pong_basketball_v0
from .games import space_invaders_easy as space_invaders_easy_v0
from .games import space_invaders_difficult as space_invaders_difficult_v0
from .games import space_invaders_alternating as space_invaders_alternating_v0
from .games import space_war as space_war_v0
from .games import surround as surround_v0
from .games import surround_erase as surround_erase_v0
from .games import tennis as tennis_v0
from .games import video_checkers as video_checkers_v0
from .games import wizard_of_wor as wizard_of_wor_v0
from .games import warlords as warlords_v0
from .games import pong_four_player as pong_four_player_v0
from .games import pong_quadrapong as pong_quadrapong_v0
from .games import pong_volleyball as pong_volleyball_v0
